# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strobesbufs.analyzers import analyzers_service_pb2 as strobesbufs_dot_analyzers_dot_analyzers__service__pb2


class RunnerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RunTask = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/RunTask',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.FromString,
                )
        self.TaskStatus = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/TaskStatus',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.FromString,
                )
        self.StopTask = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/StopTask',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.FromString,
                )
        self.GetResults = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/GetResults',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.FromString,
                )


class RunnerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RunTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TaskStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunnerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RunTask': grpc.unary_unary_rpc_method_handler(
                    servicer.RunTask,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.SerializeToString,
            ),
            'TaskStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.TaskStatus,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.SerializeToString,
            ),
            'StopTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTask,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.SerializeToString,
            ),
            'GetResults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResults,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strobesbufs.analyzers.analyzer_service.RunnerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RunnerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RunTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/RunTask',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TaskStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/TaskStatus',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/StopTask',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/GetResults',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
