# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/workflows/workflow.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strobesbufs.messier.tasks import task_pb2 as strobesbufs_dot_messier_dot_tasks_dot_task__pb2
from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/workflows/workflow.proto',
  package='strobesbufs.messier.workflow',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/workflows/workflow.proto\x12\x1cstrobesbufs.messier.workflow\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$strobesbufs/messier/tasks/task.proto\x1a strobesbufs/messier/common.proto\"\xf4\x01\n\x08Workflow\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".strobesbufs.messier.common.Status\x12+\n\x07started\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05\x65nded\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\x12-\n\x05tasks\x18\x07 \x03(\x0b\x32\x1e.strobesbufs.messier.task.Taskb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_tasks_dot_task__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,])




_WORKFLOW = _descriptor.Descriptor(
  name='Workflow',
  full_name='strobesbufs.messier.workflow.Workflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.messier.workflow.Workflow.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='strobesbufs.messier.workflow.Workflow.author', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.messier.workflow.Workflow.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='strobesbufs.messier.workflow.Workflow.started', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ended', full_name='strobesbufs.messier.workflow.Workflow.ended', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='strobesbufs.messier.workflow.Workflow.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='strobesbufs.messier.workflow.Workflow.tasks', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=428,
)

_WORKFLOW.fields_by_name['status'].enum_type = strobesbufs_dot_messier_dot_common__pb2._STATUS
_WORKFLOW.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['ended'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['tasks'].message_type = strobesbufs_dot_messier_dot_tasks_dot_task__pb2._TASK
DESCRIPTOR.message_types_by_name['Workflow'] = _WORKFLOW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'strobesbufs.messier.workflows.workflow_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.Workflow)
  })
_sym_db.RegisterMessage(Workflow)


# @@protoc_insertion_point(module_scope)
