# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/analyzers/analyzers_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.analyzers import analyzers_pb2 as strobesbufs_dot_analyzers_dot_analyzers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/analyzers/analyzers_service.proto',
  package='strobesbufs.analyzers.analyzer_service',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-strobesbufs/analyzers/analyzers_service.proto\x12&strobesbufs.analyzers.analyzer_service\x1a%strobesbufs/analyzers/analyzers.proto\"\xc7\x03\n\x0eRunTaskRequest\x12\x10\n\x08\x61nalyzer\x18\x01 \x01(\t\x12\x0b\n\x03vcs\x18\x02 \x01(\t\x12U\n\x08vcs_data\x18\x03 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry\x12W\n\tscan_data\x18\x04 \x03(\x0b\x32\x44.strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry\x12U\n\x08\x65nv_data\x18\x05 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry\x1a.\n\x0cVcsDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rScanDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0c\x45nvDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x0fRunTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x1f\n\x11TaskStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\"?\n\x12TaskStatusResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fStopTaskRequest\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\x10StopTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x11GetResultsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"M\n\x12GetResultsResponse\x12\x37\n\x07results\x18\x01 \x01(\x0b\x32&.strobesbufs.analyzers.analyzer.Result2\x9e\x04\n\rRunnerService\x12|\n\x07RunTask\x12\x36.strobesbufs.analyzers.analyzer_service.RunTaskRequest\x1a\x37.strobesbufs.analyzers.analyzer_service.RunTaskResponse\"\x00\x12\x85\x01\n\nTaskStatus\x12\x39.strobesbufs.analyzers.analyzer_service.TaskStatusRequest\x1a:.strobesbufs.analyzers.analyzer_service.TaskStatusResponse\"\x00\x12\x7f\n\x08StopTask\x12\x37.strobesbufs.analyzers.analyzer_service.StopTaskRequest\x1a\x38.strobesbufs.analyzers.analyzer_service.StopTaskResponse\"\x00\x12\x85\x01\n\nGetResults\x12\x39.strobesbufs.analyzers.analyzer_service.GetResultsRequest\x1a:.strobesbufs.analyzers.analyzer_service.GetResultsResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[strobesbufs_dot_analyzers_dot_analyzers__pb2.DESCRIPTOR,])




_RUNTASKREQUEST_VCSDATAENTRY = _descriptor.Descriptor(
  name='VcsDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=487,
)

_RUNTASKREQUEST_SCANDATAENTRY = _descriptor.Descriptor(
  name='ScanDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=536,
)

_RUNTASKREQUEST_ENVDATAENTRY = _descriptor.Descriptor(
  name='EnvDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=584,
)

_RUNTASKREQUEST = _descriptor.Descriptor(
  name='RunTaskRequest',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='analyzer', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.analyzer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcs', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcs_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.scan_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.env_data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNTASKREQUEST_VCSDATAENTRY, _RUNTASKREQUEST_SCANDATAENTRY, _RUNTASKREQUEST_ENVDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=584,
)


_RUNTASKRESPONSE = _descriptor.Descriptor(
  name='RunTaskResponse',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=647,
)


_TASKSTATUSREQUEST = _descriptor.Descriptor(
  name='TaskStatusRequest',
  full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=680,
)


_TASKSTATUSRESPONSE = _descriptor.Descriptor(
  name='TaskStatusResponse',
  full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=745,
)


_STOPTASKREQUEST = _descriptor.Descriptor(
  name='StopTaskRequest',
  full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=776,
)


_STOPTASKRESPONSE = _descriptor.Descriptor(
  name='StopTaskResponse',
  full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=839,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
  name='GetResultsRequest',
  full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=872,
)


_GETRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetResultsResponse',
  full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=951,
)

_RUNTASKREQUEST_VCSDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_SCANDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_ENVDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST.fields_by_name['vcs_data'].message_type = _RUNTASKREQUEST_VCSDATAENTRY
_RUNTASKREQUEST.fields_by_name['scan_data'].message_type = _RUNTASKREQUEST_SCANDATAENTRY
_RUNTASKREQUEST.fields_by_name['env_data'].message_type = _RUNTASKREQUEST_ENVDATAENTRY
_GETRESULTSRESPONSE.fields_by_name['results'].message_type = strobesbufs_dot_analyzers_dot_analyzers__pb2._RESULT
DESCRIPTOR.message_types_by_name['RunTaskRequest'] = _RUNTASKREQUEST
DESCRIPTOR.message_types_by_name['RunTaskResponse'] = _RUNTASKRESPONSE
DESCRIPTOR.message_types_by_name['TaskStatusRequest'] = _TASKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['TaskStatusResponse'] = _TASKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['StopTaskRequest'] = _STOPTASKREQUEST
DESCRIPTOR.message_types_by_name['StopTaskResponse'] = _STOPTASKRESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetResultsResponse'] = _GETRESULTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunTaskRequest = _reflection.GeneratedProtocolMessageType('RunTaskRequest', (_message.Message,), {

  'VcsDataEntry' : _reflection.GeneratedProtocolMessageType('VcsDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_VCSDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry)
    })
  ,

  'ScanDataEntry' : _reflection.GeneratedProtocolMessageType('ScanDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_SCANDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry)
    })
  ,

  'EnvDataEntry' : _reflection.GeneratedProtocolMessageType('EnvDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_ENVDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry)
    })
  ,
  'DESCRIPTOR' : _RUNTASKREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest)
  })
_sym_db.RegisterMessage(RunTaskRequest)
_sym_db.RegisterMessage(RunTaskRequest.VcsDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.ScanDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.EnvDataEntry)

RunTaskResponse = _reflection.GeneratedProtocolMessageType('RunTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNTASKRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskResponse)
  })
_sym_db.RegisterMessage(RunTaskResponse)

TaskStatusRequest = _reflection.GeneratedProtocolMessageType('TaskStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUSREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusRequest)
  })
_sym_db.RegisterMessage(TaskStatusRequest)

TaskStatusResponse = _reflection.GeneratedProtocolMessageType('TaskStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUSRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusResponse)
  })
_sym_db.RegisterMessage(TaskStatusResponse)

StopTaskRequest = _reflection.GeneratedProtocolMessageType('StopTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPTASKREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskRequest)
  })
_sym_db.RegisterMessage(StopTaskRequest)

StopTaskResponse = _reflection.GeneratedProtocolMessageType('StopTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPTASKRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskResponse)
  })
_sym_db.RegisterMessage(StopTaskResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponse = _reflection.GeneratedProtocolMessageType('GetResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsResponse)
  })
_sym_db.RegisterMessage(GetResultsResponse)


_RUNTASKREQUEST_VCSDATAENTRY._options = None
_RUNTASKREQUEST_SCANDATAENTRY._options = None
_RUNTASKREQUEST_ENVDATAENTRY._options = None

_RUNNERSERVICE = _descriptor.ServiceDescriptor(
  name='RunnerService',
  full_name='strobesbufs.analyzers.analyzer_service.RunnerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=954,
  serialized_end=1496,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTask',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.RunTask',
    index=0,
    containing_service=None,
    input_type=_RUNTASKREQUEST,
    output_type=_RUNTASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TaskStatus',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.TaskStatus',
    index=1,
    containing_service=None,
    input_type=_TASKSTATUSREQUEST,
    output_type=_TASKSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopTask',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.StopTask',
    index=2,
    containing_service=None,
    input_type=_STOPTASKREQUEST,
    output_type=_STOPTASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResults',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.GetResults',
    index=3,
    containing_service=None,
    input_type=_GETRESULTSREQUEST,
    output_type=_GETRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNNERSERVICE)

DESCRIPTOR.services_by_name['RunnerService'] = _RUNNERSERVICE

# @@protoc_insertion_point(module_scope)
