# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/tasks/task.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2
from strobesbufs.messier.functions import function_pb2 as strobesbufs_dot_messier_dot_functions_dot_function__pb2
from strobesbufs.messier.analyzers import analyzer_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/tasks/task.proto',
  package='strobesbufs.messier.task',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$strobesbufs/messier/tasks/task.proto\x12\x18strobesbufs.messier.task\x1a\x1fgoogle/protobuf/timestamp.proto\x1a strobesbufs/messier/common.proto\x1a,strobesbufs/messier/functions/function.proto\x1a,strobesbufs/messier/analyzers/analyzer.proto\"\xcb\x02\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".strobesbufs.messier.common.Status\x12+\n\x07started\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05\x65nded\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x08\x61nalyzer\x18\x05 \x01(\x0b\x32&.strobesbufs.messier.analyzer.AnalyzerH\x00\x12:\n\x08\x66unction\x18\x06 \x01(\x0b\x32&.strobesbufs.messier.function.FunctionH\x00\x12\x12\n\ndepends_on\x18\x07 \x01(\t\x12\x10\n\x08parallel\x18\x08 \x01(\x08\x42\x0b\n\ttask_typeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_function__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2.DESCRIPTOR,])




_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='strobesbufs.messier.task.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.messier.task.Task.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.messier.task.Task.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='strobesbufs.messier.task.Task.started', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ended', full_name='strobesbufs.messier.task.Task.ended', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analyzer', full_name='strobesbufs.messier.task.Task.analyzer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='strobesbufs.messier.task.Task.function', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depends_on', full_name='strobesbufs.messier.task.Task.depends_on', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parallel', full_name='strobesbufs.messier.task.Task.parallel', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task_type', full_name='strobesbufs.messier.task.Task.task_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=226,
  serialized_end=557,
)

_TASK.fields_by_name['status'].enum_type = strobesbufs_dot_messier_dot_common__pb2._STATUS
_TASK.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASK.fields_by_name['ended'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASK.fields_by_name['analyzer'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2._ANALYZER
_TASK.fields_by_name['function'].message_type = strobesbufs_dot_messier_dot_functions_dot_function__pb2._FUNCTION
_TASK.oneofs_by_name['task_type'].fields.append(
  _TASK.fields_by_name['analyzer'])
_TASK.fields_by_name['analyzer'].containing_oneof = _TASK.oneofs_by_name['task_type']
_TASK.oneofs_by_name['task_type'].fields.append(
  _TASK.fields_by_name['function'])
_TASK.fields_by_name['function'].containing_oneof = _TASK.oneofs_by_name['task_type']
DESCRIPTOR.message_types_by_name['Task'] = _TASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'strobesbufs.messier.tasks.task_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.task.Task)
  })
_sym_db.RegisterMessage(Task)


# @@protoc_insertion_point(module_scope)
