# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/analyzers/naabu.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/analyzers/naabu.proto',
  package='strobesbufs.messier.analyzer',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)strobesbufs/messier/analyzers/naabu.proto\x12\x1cstrobesbufs.messier.analyzer\x1a strobesbufs/messier/common.proto\"J\n\x05Naabu\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x31\n\x03log\x18\x02 \x01(\x0e\x32$.strobesbufs.messier.common.LogLevelb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,])




_NAABU = _descriptor.Descriptor(
  name='Naabu',
  full_name='strobesbufs.messier.analyzer.Naabu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='strobesbufs.messier.analyzer.Naabu.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='strobesbufs.messier.analyzer.Naabu.log', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=183,
)

_NAABU.fields_by_name['log'].enum_type = strobesbufs_dot_messier_dot_common__pb2._LOGLEVEL
DESCRIPTOR.message_types_by_name['Naabu'] = _NAABU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Naabu = _reflection.GeneratedProtocolMessageType('Naabu', (_message.Message,), {
  'DESCRIPTOR' : _NAABU,
  '__module__' : 'strobesbufs.messier.analyzers.naabu_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.analyzer.Naabu)
  })
_sym_db.RegisterMessage(Naabu)


# @@protoc_insertion_point(module_scope)
