# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/analyzers/analyzer.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier.analyzers import bandit_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2
from strobesbufs.messier.analyzers import subfinder_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2
from strobesbufs.messier.analyzers import naabu_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2
from strobesbufs.messier.analyzers import wappalyzer_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/analyzers/analyzer.proto',
  package='strobesbufs.messier.analyzer',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/analyzers/analyzer.proto\x12\x1cstrobesbufs.messier.analyzer\x1a*strobesbufs/messier/analyzers/bandit.proto\x1a-strobesbufs/messier/analyzers/subfinder.proto\x1a)strobesbufs/messier/analyzers/naabu.proto\x1a.strobesbufs/messier/analyzers/wappalyzer.proto\"\x82\x02\n\x08\x41nalyzer\x12\x36\n\x06\x42\x61ndit\x18\x01 \x01(\x0b\x32$.strobesbufs.messier.analyzer.BanditH\x00\x12<\n\tSubfinder\x18\x02 \x01(\x0b\x32\'.strobesbufs.messier.analyzer.SubfinderH\x00\x12\x34\n\x05Naabu\x18\x03 \x01(\x0b\x32#.strobesbufs.messier.analyzer.NaabuH\x00\x12>\n\nWappalyzer\x18\x04 \x01(\x0b\x32(.strobesbufs.messier.analyzer.WappalyzerH\x00\x42\n\n\x08\x61nalyzerb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2.DESCRIPTOR,])




_ANALYZER = _descriptor.Descriptor(
  name='Analyzer',
  full_name='strobesbufs.messier.analyzer.Analyzer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Bandit', full_name='strobesbufs.messier.analyzer.Analyzer.Bandit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Subfinder', full_name='strobesbufs.messier.analyzer.Analyzer.Subfinder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Naabu', full_name='strobesbufs.messier.analyzer.Analyzer.Naabu', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Wappalyzer', full_name='strobesbufs.messier.analyzer.Analyzer.Wappalyzer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='analyzer', full_name='strobesbufs.messier.analyzer.Analyzer.analyzer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=261,
  serialized_end=519,
)

_ANALYZER.fields_by_name['Bandit'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2._BANDIT
_ANALYZER.fields_by_name['Subfinder'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2._SUBFINDER
_ANALYZER.fields_by_name['Naabu'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2._NAABU
_ANALYZER.fields_by_name['Wappalyzer'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2._WAPPALYZER
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Bandit'])
_ANALYZER.fields_by_name['Bandit'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Subfinder'])
_ANALYZER.fields_by_name['Subfinder'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Naabu'])
_ANALYZER.fields_by_name['Naabu'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Wappalyzer'])
_ANALYZER.fields_by_name['Wappalyzer'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
DESCRIPTOR.message_types_by_name['Analyzer'] = _ANALYZER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Analyzer = _reflection.GeneratedProtocolMessageType('Analyzer', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZER,
  '__module__' : 'strobesbufs.messier.analyzers.analyzer_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.analyzer.Analyzer)
  })
_sym_db.RegisterMessage(Analyzer)


# @@protoc_insertion_point(module_scope)
